@@ -79,12 +79,37 @@ class UnwrappedLine(object):
       # because these may use it for their decision.
       token.split_penalty += _SplitPenalty(prev_token, token)
       token.must_break_before = _MustBreakBefore(prev_token, token)
-      token.can_break_before = (token.must_break_before or
-                                _CanBreakBefore(prev_token, token))
+      token.can_break_before = (
+          token.must_break_before or _CanBreakBefore(prev_token, token))
 
       prev_length = token.total_length
       prev_token = token
 
+  def Split(self):
+    """Split the line at semicolons."""
+    if not self.has_semicolon or self.disable:
+      return [self]
+
+    uwlines = []
+    uwline = UnwrappedLine(self.depth)
+    for tok in self._tokens:
+      if tok.value == ';':
+        uwlines.append(uwline)
+        uwline = UnwrappedLine(self.depth)
+      else:
+        uwline.AppendToken(tok)
+
+    if uwline.tokens:
+      uwlines.append(uwline)
+
+    for uwline in uwlines:
+      pytree_utils.SetNodeAnnotation(uwline.first.node,
+                                     pytree_utils.Annotation.MUST_SPLIT, True)
+      uwline.first.previous_token = None
+      uwline.last.next_token = None
+
+    return uwlines
+
   ############################################################################
   # Token Access and Manipulation Methods                                    #
   ############################################################################
@@ -176,6 +201,10 @@ class UnwrappedLine(object):
   def is_comment(self):
     return self.first.is_comment
 
+  @property
+  def has_semicolon(self):
+    return any(tok.value == ';' for tok in self._tokens)
+
 
 def _IsIdNumberStringToken(tok):
   return tok.is_keyword or tok.is_name or tok.is_number or tok.is_string
@@ -233,6 +262,14 @@ def _SpaceRequiredBetween(left, right):
       (left.is_keyword or left.is_name)):
     # Don't merge two keywords/identifiers.
     return True
+  if (format_token.Subtype.SUBSCRIPT_COLON in left.subtypes or
+      format_token.Subtype.SUBSCRIPT_COLON in right.subtypes):
+    # A subscript shouldn't have spaces separating its colons.
+    return False
+  if (format_token.Subtype.TYPED_NAME in left.subtypes or
+      format_token.Subtype.TYPED_NAME in right.subtypes):
+    # A typed argument should have a space after the colon.
+    return True
   if left.is_string:
     if (rval == '=' and format_token.Subtype.DEFAULT_OR_NAMED_ASSIGN_ARG_LIST in
         right.subtypes):
@@ -246,6 +283,9 @@ def _SpaceRequiredBetween(left, right):
   if left.is_binary_op and lval != '**' and _IsUnaryOperator(right):
     # Space between the binary opertor and the unary operator.
     return True
+  if left.is_keyword and _IsUnaryOperator(right):
+    # Handle things like "not -3 < x".
+    return True
   if _IsUnaryOperator(left) and _IsUnaryOperator(right):
     # No space between two unary operators.
     return False
@@ -261,15 +301,10 @@ def _SpaceRequiredBetween(left, right):
     # The previous token was a unary op. No space is desired between it and
     # the current token.
     return False
-  if (format_token.Subtype.SUBSCRIPT_COLON in left.subtypes or
-      format_token.Subtype.SUBSCRIPT_COLON in right.subtypes):
-    # A subscript shouldn't have spaces separating its colons.
-    return False
   if (format_token.Subtype.DEFAULT_OR_NAMED_ASSIGN in left.subtypes or
       format_token.Subtype.DEFAULT_OR_NAMED_ASSIGN in right.subtypes):
     # A named argument or default parameter shouldn't have spaces around it.
-    # However, a typed argument should have a space after the colon.
-    return lval == ':' or style.Get('SPACES_AROUND_DEFAULT_OR_NAMED_ASSIGN')
+    return style.Get('SPACES_AROUND_DEFAULT_OR_NAMED_ASSIGN')
   if (format_token.Subtype.VARARGS_LIST in left.subtypes or
       format_token.Subtype.VARARGS_LIST in right.subtypes):
     return False
@@ -280,6 +315,9 @@ def _SpaceRequiredBetween(left, right):
   if lval == '@' and format_token.Subtype.DECORATOR in left.subtypes:
     # Decorators shouldn't be separated from the 'at' sign.
     return False
+  if left.is_keyword and rval == '.' or lval == '.' and right.is_keyword:
+    # Add space between keywords and dots.
+    return True
   if lval == '.' or rval == '.':
     # Don't place spaces between dots.
     return False
